@@ -78,12 +78,27 @@ private:
 
 static bool ignoreBlkDevice(const QString& blkPath, QSharedPointer<DBlockDevice> blk, QSharedPointer<DDiskDevice> drv)
 {
+    bool isOptical = drv->mediaCompatibility().join(",").contains("optical");
+    if (!blk->hasFileSystem() && blk->size() < 1024 && !isOptical) {   // a super block is at least 1024 bytes, a full filesystem always have a superblock.
+        qWarning() << "block device is ignored cause it's size is less than 1024" << blkPath;
+        return true;
+    }
+
+    // 过滤snap产生的loop设备
+    if(blk->isLoopDevice()){ // loop devices' display status only determind by GA_HideLoopPartitions property.
+        if (DFMApplication::genericAttribute(DFMApplication::GA_HideLoopPartitions).toBool()) {
+            qDebug()  << "block device is ignored by loop device:"  << blkPath;
+            return true;
+        } else {
+            return false;
+        }
+    }
+
     if (blk->hintIgnore()) {
         qWarning()  << "block device is ignored by hintIgnore:"  << blkPath;
         return true;
     }
 
-    bool isOptical = drv->mediaCompatibility().join(",").contains("optical");
     if (!blk->hasFileSystem() && !isOptical && !blk->isEncrypted()) {
         if (!drv->removable()){ // 满足外围条件的本地磁盘，直接遵循以前的处理直接 continue
             qWarning()  << "block device is ignored by wrong removeable set for system disk:"  << blkPath;
@@ -91,11 +106,6 @@ static bool ignoreBlkDevice(const QString& blkPath, QSharedPointer<DBlockDevice>
         }
     }
 
-    if (!blk->hasFileSystem() && blk->size() < 1024 && !isOptical) {   // a super block is at least 1024 bytes, a full filesystem always have a superblock.
-        qWarning() << "block device is ignored cause it's size is less than 1024";
-        return true;
-    }
-
     if (blk->cryptoBackingDevice().length() > 1) {
         qWarning()  << "block device is ignored by crypted back device:"  << blkPath;
         return true;
@@ -107,12 +117,6 @@ static bool ignoreBlkDevice(const QString& blkPath, QSharedPointer<DBlockDevice>
         return true;
     }
 
-    // 过滤snap产生的loop设备
-    if(blk->isLoopDevice() && DFMApplication::genericAttribute(DFMApplication::GA_HideLoopPartitions).toBool()){
-        qDebug()  << "block device is ignored by loop device:"  << blkPath;
-        return true;
-    }
-
     if(blk->hasPartition()){
         QSharedPointer<DBlockPartition> partition(DDiskManager::createBlockPartition(blkPath));
         if(!partition.isNull()){
