@@ -76,6 +76,7 @@
 #include <QUrlQuery>
 #include <QRegularExpression>
 
+#include <thread>
 #include <unistd.h>
 #include <gio/gio.h>
 
@@ -283,12 +284,19 @@ public:
                 searchStartOffset = searchEndOffset = 0;
                 searchDirList.removeAt(0);
             }
-        }
 
-        // 如果路径中存在链接，需要将其还原，用于展示
-        if (m_hasSymLink) {
-            for (auto &path : searchResults) {
-                path.replace(m_newPrefix, m_oldPrefix);
+            // 如果路径中存在链接，需要将其还原，用于展示
+            if (m_hasSymLink) {
+                for (auto &path : searchResults) {
+                    path.replace(m_newPrefix, m_oldPrefix);
+                    if (m_isAddDataPrefix && path.startsWith("/data"))
+                        path.remove(0, 5);
+                }
+            } else if (m_isAddDataPrefix) {
+                for (auto &path : searchResults) {
+                    if (path.startsWith("/data"))
+                        path.remove(0, 5);
+                }
             }
         }
 
@@ -320,16 +328,18 @@ public:
     }
 
     ///
-    /// \brief setSymLink 如果搜索路径中存在链接目录，记录一些参数用于搜索结果还原
+    /// \brief setPathPropertity 设置路径属性
     /// \param hasSymLink 是否存在链接目录
     /// \param oldPrefix 原始前缀
     /// \param newPrefix 修改后的前缀
+    /// \param isAddDataPrefix 是否添加了data目录前缀
     ///
-    void setSymLink(bool hasSymLink, const QString &oldPrefix, const QString &newPrefix)
+    void setPathPropertity(bool hasSymLink, const QString &oldPrefix, const QString &newPrefix, const bool isAddDataPrefix)
     {
         m_hasSymLink = hasSymLink;
         m_oldPrefix = oldPrefix;
         m_newPrefix = newPrefix;
+        m_isAddDataPrefix = isAddDataPrefix;
     }
 
 private:
@@ -342,6 +352,7 @@ private:
     mutable QStringList searchResults;
 
     bool m_hasSymLink = false;
+    bool m_isAddDataPrefix = false;
     QString m_oldPrefix;
     QString m_newPrefix;
 
@@ -381,18 +392,6 @@ QString printList(BTreeNode *pNode)
         }
     }
 
-    // 防止后续pathList越界，先判断
-    QStringList pathList = fullPath.split('/');
-    if (pathList.isEmpty() || pathList.size() < 2) {
-        return "";
-    }
-    QString t_prefix = pathList.at(1);
-
-    if (t_prefix == "boot" || t_prefix == "dev" || t_prefix == "proc" || t_prefix == "sys"
-            || t_prefix == "root" || t_prefix == "run") {
-        return "";
-    }
-
     return fullPath;
 }
 
@@ -631,11 +630,11 @@ bool FileController::openFile(const QSharedPointer<DFMOpenFileEvent> &event) con
             dialogManager->showErrorDialog(tr("Unable to find the original file"), QString());
             return false;
         }
-        if (!linkInfo->exists()) {
-            dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), fileUrl);
+        const_cast<DUrl &>(fileUrl) = linkInfo->redirectedFileUrl();
+        if (!linkInfo->exists() && !FileUtils::isSmbUnmountedFile(fileUrl)) {
+            dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), pfile->fileUrl());
             return false;
         }
-        const_cast<DUrl &>(fileUrl) = linkInfo->redirectedFileUrl();
     }
 
     if (FileUtils::isExecutableScript(fileUrl.toLocalFile())) {
@@ -687,11 +686,11 @@ bool FileController::openFiles(const QSharedPointer<DFMOpenFilesEvent> &event) c
                 dialogManager->showErrorDialog(tr("Unable to find the original file"), QString());
                 continue;
             }
-            if (!linkInfo->exists()) {
-                dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), fileUrl);
+            fileUrl = linkInfo->redirectedFileUrl();
+            if (!linkInfo->exists() && !FileUtils::isSmbUnmountedFile(fileUrl)) {
+                dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), pfile->fileUrl());
                 continue;
             }
-            fileUrl = linkInfo->redirectedFileUrl();
         }
 
         if (FileUtils::isExecutableScript(fileUrl.toLocalFile())) {
@@ -750,11 +749,11 @@ bool FileController::openFileByApp(const QSharedPointer<DFMOpenFileByAppEvent> &
             dialogManager->showErrorDialog(tr("Unable to find the original file"), QString());
             return false;
         }
-        if (!linkInfo->exists()) {
-            dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), fileUrl);
+        const_cast<DUrl &>(fileUrl) = linkInfo->redirectedFileUrl();
+        if (!linkInfo->exists() && !FileUtils::isSmbUnmountedFile(fileUrl)) {
+            dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), pfile->fileUrl());
             return false;
         }
-        const_cast<DUrl &>(fileUrl) = linkInfo->redirectedFileUrl();
     }
     return FileUtils::openFilesByApp(event->appName(), {fileUrl.toString()});
 }
@@ -776,12 +775,11 @@ bool FileController::openFilesByApp(const QSharedPointer<DFMOpenFilesByAppEvent>
                 dialogManager->showErrorDialog(tr("Unable to find the original file"), QString());
                 continue;
             }
-
-            if (!linkInfo->exists()) {
-                dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), fileUrl);
-                continue;
-            }
             fileUrl = linkInfo->redirectedFileUrl();
+            if (!linkInfo->exists() && !FileUtils::isSmbUnmountedFile(fileUrl)) {
+                dialogManager->showBreakSymlinkDialog(linkInfo->fileName(), pfile->fileUrl());
+                continue;
+            } 
         }
         QString url = fileUrl.toLocalFile();
         if (FileUtils::isFileWindowsUrlShortcut(url)) {
@@ -882,7 +880,7 @@ bool FileController::renameFileByGio(const DUrl &oldUrl, const DUrl &newUrl) con
     }
 
     //获取当前目录
-    QString curd = QDir::current().path();
+    const QString &curd = QDir::currentPath();
 
     GError *error = nullptr;
     if (!QDir::setCurrent(to)) {
@@ -933,14 +931,30 @@ bool FileController::renameFile(const QSharedPointer<DFMRenameEvent> &event) con
         QString filePath = oldUrl.toLocalFile();
         Properties desktop(filePath, "Desktop Entry");
         QString key;
-        QString localKey = QString("Name[%1]").arg(QLocale::system().name());
+        const QString local = QLocale::system().name();
+        const QString keyTemplate = QString("Name[%1]");
+        QString localKey = keyTemplate.arg(local);
         if (desktop.contains(localKey)) {
             key = localKey;
         } else {
-            key = "Name";
+            // split xx_XX
+            auto splitedLocal = local.trimmed().split("_");
+            if (!splitedLocal.isEmpty()
+                    && desktop.contains(localKey = keyTemplate.arg(splitedLocal.first())))
+                key = localKey;
+             else
+                key = "Name";
         }
 
+        const QString currentName = oldfilePointer->fileDisplayName();
+
         const QString old_name = desktop.value(key).toString();
+        // 名称没有改变
+        if (currentName == newfilePointer->fileName()) {
+            qDebug() << "rename" << filePath << "currentName"
+                     << currentName << "key" << key  << old_name << "new name" << newfilePointer->fileName();
+            return true;
+        }
 
         desktop.set(key, newfilePointer->fileName());
         desktop.set("X-Deepin-Vendor", QStringLiteral("user-custom"));
@@ -954,17 +968,6 @@ bool FileController::renameFile(const QSharedPointer<DFMRenameEvent> &event) con
     } else {
         if (newFilePath.contains("gvfs/mtp")) {
             result = renameFileByGio(oldUrl, newUrl);
-
-            // mtp 目录无法删除，因此采用复制再删除的模式
-            if (!result && QFileInfo(file).isDir()) {
-                result = QProcess::execute("cp -r \"" + file.fileName().toUtf8() + "\" \"" + newFilePath.toUtf8() + "\"") == 0;
-
-                if (result) {
-                    QProcess::execute("rm -r \"" + file.fileName().toUtf8() + "\"");
-                } else {
-                    QProcess::execute("rm -r \"" + newFilePath.toUtf8() + "\"");
-                }
-            }
         }
 
         if (!result) {
@@ -975,6 +978,17 @@ bool FileController::renameFile(const QSharedPointer<DFMRenameEvent> &event) con
             result = QProcess::execute("mv \"" + file.fileName().toUtf8() + "\" \"" + newFilePath.toUtf8() + "\"") == 0;
         }
 
+        // mtp ftp(和ftp搭建的配置有关系) 目录无法删除，因此采用复制再删除的模式
+        if (!result && (FileUtils::isFtpFile(oldUrl) || newFilePath.contains("gvfs/mtp")) && QFileInfo(file).isDir()) {
+            result = QProcess::execute("cp -r \"" + file.fileName().toUtf8() + "\" \"" + newFilePath.toUtf8() + "\"") == 0;
+
+            if (result) {
+                QProcess::execute("rm -r \"" + file.fileName().toUtf8() + "\"");
+            } else {
+                QProcess::execute("rm -r \"" + newFilePath.toUtf8() + "\"");
+            }
+        }
+
         if (result) {
             DFMEventDispatcher::instance()->processEvent<DFMSaveOperatorEvent>(event, dMakeEventPointer<DFMRenameEvent>(nullptr, newUrl, oldUrl));
 
@@ -1073,10 +1087,11 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
     if (!event.isNull() && !qvariant_cast<DUrlList>(event->cutData()).isEmpty()) {
         job->setCurTrashData(event->cutData());
     }
+
     // 当前线程退出，局不变currentJob被释放，但是ErrorHandle线程还在使用它
     // fix bug 31324,判断当前操作是否是清空回收站，是就在结束时改变清空回收站状态
     bool bdoingcleartrash = DFileService::instance()->getDoClearTrashState();
-    if (action == DFMGlobal::CutAction && bdoingcleartrash && list.count() == 1 &&
+    if (action == DFMGlobal::DeleteAction && bdoingcleartrash && list.count() == 1 &&
             list.first().toString().endsWith(".local/share/Trash/files")) {
         connect(job.data(), &QThread::finished, this, [ = ]() {
             DFileService::instance()->setDoClearTrashState(false);
@@ -1089,7 +1104,7 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
 
     // sp3 feature： 复制时不进行校验，后面调整为独立的功能
     job->setFileHints(job->fileHints() | DFileCopyMoveJob::DontIntegrityChecking);
-    if (action == DFMGlobal::CutAction && !target.isValid()) {
+    if (action == DFMGlobal::DeleteAction) {
         // for remove mode
         job->setActionOfErrorType(DFileCopyMoveJob::NonexistenceError, DFileCopyMoveJob::SkipAction);
     }
@@ -1131,7 +1146,7 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
             dialogManager->taskDialog()->removeTaskJob(fileJob.data());
             fileJob->disconnect();
             fileJob.reset(nullptr);
-            qInfo() << "file copy error handle release!";
+            qDebug() << "file copy error handle release!";
         }
 
         // 处理任务对话框显示之前的错误, 无法处理的错误将立即弹出对话框处理
@@ -1220,14 +1235,26 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
     });
 
     job->setErrorHandle(error_handle, slient ? nullptr : error_handle->thread());
-    // fix：原来本来没有 movemode，当前彻底删除文件时要转换 mode 为 movemode，
-    //     原来剪切和删除都是用的 cutmode 来表示，这会导致进度条无法区分剪切和删除
-    //     为了区分剪切和删除，这里使用 traget 是否为空来判断当前的操作是剪切还是删除
-    if (target.isEmpty())
-        action = DFMGlobal::UnknowAction;
-    job->setMode(action == DFMGlobal::CopyAction
-                 ? DFileCopyMoveJob::CopyMode
-                 : (action == DFMGlobal::CutAction ? DFileCopyMoveJob::CutMode : DFileCopyMoveJob::MoveMode));
+
+    DFileCopyMoveJob::Mode mode = DFileCopyMoveJob::CopyMode;
+    switch (action) {
+    case DFMGlobal::CopyAction:
+        mode = DFileCopyMoveJob::CopyMode;
+        break;
+    case DFMGlobal::CutAction:
+        mode = DFileCopyMoveJob::CutMode;
+        break;
+    case DFMGlobal::DeleteAction:
+        mode = DFileCopyMoveJob::MoveMode;
+        break;
+    case DFMGlobal::RemoteAction:
+        mode = DFileCopyMoveJob::RemoteMode;
+        break;
+    default:
+        mode = DFileCopyMoveJob::UnknowMode;
+    }
+    job->setMode(mode);
+
     job->start(list, target);
     //走以前的老流程，阻塞主线去拷贝或者删除
     if (bold) {
@@ -1263,6 +1290,10 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
         }
         //处理复制、粘贴和剪切(拷贝)结束后操作 fix bug 35855
         this->dealpasteEnd(targetUrlList, event);
+        //! 判断目标目录是否是保险箱目录如果是，发送信号激活计算保险大小的线程
+        if(!targetUrlList.isEmpty() && targetUrlList.at(0).toLocalFile().contains(VaultController::makeVaultLocalPath())) {
+            emit VaultController::ins()->sigFinishedCopyFile();
+        }
     });
 
     return job->targetUrlList();
@@ -1280,7 +1311,7 @@ void FileController::dealpasteEnd(const DUrlList &list, const QSharedPointer<DFM
         return;
     }
 
-    if (event->action() == DFMGlobal::CopyAction) {
+    if (event->action() == DFMGlobal::CopyAction || event->action() == DFMGlobal::RemoteAction) {
         DFMEventDispatcher::instance()->processEvent<DFMSaveOperatorEvent>(event, dMakeEventPointer<DFMDeleteEvent>(nullptr, valid_files, true), true);
     } else {
         const QString targetDir(QFileInfo(event->urlList().first().toLocalFile()).absolutePath());
@@ -1322,7 +1353,7 @@ bool FileController::deleteFiles(const QSharedPointer<DFMDeleteEvent> &event) co
     //    }
 
 
-    bool ok = !pasteFilesV2(nullptr, DFMGlobal::CutAction, event->fileUrlList(), DUrl(), event->silent(), event->force(), true).isEmpty();
+    bool ok = !pasteFilesV2(nullptr, DFMGlobal::DeleteAction, event->fileUrlList(), DUrl(), event->silent(), event->force(), true).isEmpty();
     for (const auto &url : event->fileUrlList()) {
         if (url.toLocalFile().contains("/mtp:")) {
             DUrl mtpUrl(url);
@@ -1349,7 +1380,7 @@ DUrlList FileController::moveToTrash(const QSharedPointer<DFMMoveToTrashEvent> &
 
     // save event
     const QVariant &result = DFMEventDispatcher::instance()->processEvent<DFMGetChildrensEvent>(event->sender(), DUrl::fromTrashFile("/"),
-                                                                                                QStringList(), QDir::AllEntries | QDir::Hidden);
+                                                                                                QStringList(), QDir::AllEntries | QDir::Hidden | QDir::System);
     const QList<DAbstractFileInfoPointer> &infos = qvariant_cast<QList<DAbstractFileInfoPointer>>(result);
 
     if (infos.isEmpty()) {
@@ -1441,6 +1472,15 @@ DUrlList FileController::pasteFile(const QSharedPointer<DFMPasteEvent> &event) c
         */
     use_old_filejob = !QFile("/proc/thread-self/io").exists();
 #endif
+    // 将最近使用文件url转换为本地url
+    DUrlList urlList = event->urlList();
+    if (!urlList.isEmpty() && urlList.first().isRecentFile()) {
+        for (auto &url : urlList) {
+            const auto &local = url.path();
+            url = DUrl::fromLocalFile(local);
+        }
+        event->setData(urlList);
+    }
 
     DUrlList list;
     //pasteFilesV1走以前的流程
@@ -1495,7 +1535,7 @@ bool FileController::mkdir(const QSharedPointer<DFMMkdirEvent> &event) const
         // 创建文件夹失败，提示错误信息
         QString strErr = tr("Unable to create files here: %1").arg(strerror(errno));
         DThreadUtil::runInMainThread(dialogManager, &DialogManager::showMessageDialog,
-                                     DialogManager::msgWarn, strErr, "", tr("Confirm"));
+                                     DialogManager::msgWarn, strErr, "", tr("Confirm","button"));
     }
 
     return ok;
@@ -1530,7 +1570,14 @@ bool FileController::setPermissions(const QSharedPointer<DFMSetPermissionEvent>
 
     event->accept();
 
-    return file.setPermissions(event->permissions());
+    if (file.setPermissions(event->permissions())) {
+        // 如果是快捷方式，发送文件属性变化信号，重绘item
+        QFileInfo fileInfo(file);
+        if (fileInfo.isSymLink())
+            DAbstractFileWatcher::ghostSignal(event->url().parentUrl(), &DAbstractFileWatcher::fileAttributeChanged, event->url());
+        return true;
+    }
+    return false;
 }
 
 bool FileController::shareFolder(const QSharedPointer<DFMFileShareEvent> &event) const
@@ -1694,7 +1741,9 @@ public:
 
     bool match(const QString &path, const QString &name)
     {
-        for (auto pattern : patternList) {
+        // 这里可能会析构 先复制一份再循环
+        const QList<QPair<QString, QString>> patternListNew = patternList;
+        for (auto pattern : patternListNew) {
             QRegularExpression re(QString(), QRegularExpression::MultilineOption);
 
             if (!pattern.first.isEmpty()) {
@@ -1933,8 +1982,16 @@ bool FileDirIterator::enableIteratorByKeyword(const QString &keyword)
     static ComDeepinAnythingInterface anything("com.deepin.anything", "/com/deepin/anything",
                                                QDBusConnection::systemBus());
 
+    bool isAddDataPrefix = false;
     if (!anything.hasLFT(pathForSearching)) {
-        return false;
+        if (pathForSearching.startsWith("/home") && QDir("/data/home").exists()) {
+            pathForSearching.prepend("/data");
+            if (!anything.hasLFT(pathForSearching))
+                return false;
+            isAddDataPrefix = true;
+        } else {
+            return false;
+        }
     } else {
         qDebug() << "support quick search for: " << pathForSearching;
     }
@@ -1950,13 +2007,16 @@ bool FileDirIterator::enableIteratorByKeyword(const QString &keyword)
         delete iterator;
 
     iterator = new DFMAnythingDirIterator(&anything, pathForSearching, keyword);
-    static_cast<DFMAnythingDirIterator *>(iterator)->setSymLink(hasLink, oldPrefix, newPrefix);
+    static_cast<DFMAnythingDirIterator *>(iterator)->setPathPropertity(hasLink, oldPrefix, newPrefix, isAddDataPrefix);
 
     return true;
 #endif // DISABLE_QUICK_SEARCH
 
 #ifdef DISABLE_QUICK_SEARCH
     const QString pathForSearching = iterator->url().toLocalFile();
+    if (!DFSearch::isSupportFSearch(pathForSearching))
+        return false;
+
     if (iterator)
         delete iterator;
 
