@@ -95,6 +95,11 @@ UDiskListener::UDiskListener(QObject *parent):
     fileService->setFileUrlHandler(DEVICE_SCHEME, "", this);
 }
 
+UDiskListener::~UDiskListener()
+{
+    DFileService::unsetFileUrlHandler(this);
+}
+
 void UDiskListener::initDiskManager()
 {
     m_diskMgr = new DDiskManager(this);
@@ -570,6 +575,33 @@ bool UDiskListener::isFromNativeDisk(const QString &uuid)
     return ret;
 }
 
+bool UDiskListener::isFromNativeBlockDev(const QString &mntPath)
+{
+    static const char * const filename = "/proc/mounts";
+    FILE *mntfile;
+    struct mntent mntent;
+    bool ret = false;
+    char strs[1024] = {0};
+
+    mntfile = setmntent(filename, "r");
+    if (!mntfile) {
+        qCritical() << "Failed to read mtab file, error: " << strerror(errno);
+        return ret;
+    }
+
+    while ((getmntent_r(mntfile, &mntent, strs, sizeof (strs)))) {
+        QString name(mntent.mnt_fsname);
+        QString path(mntent.mnt_dir);
+        if (mntPath == path && name.startsWith("/dev")) {
+            ret = true;
+            break;
+        }
+    }
+
+    endmntent(mntfile);
+    return ret;
+}
+
 void UDiskListener::addMountDiskInfo(const QDiskInfo &diskInfo)
 {
     qDebug() << diskInfo;
