@@ -41,6 +41,9 @@ public:
     void setISOImage(DUrl image);
     void setJobWindowId(int wid);
     void setDefaultVolName(const QString &volName);
+    void setDiscAndFsInfo(int type, QString filesystem, QString version);
+    static bool isSupportedUDVersion(const QString &version);
+    static bool isSupportedUDMedium(int type);
 
 private:
     QScopedPointer<BurnOptDialogPrivate> d_ptr;
