@@ -267,6 +267,7 @@ FilePreviewDialog::FilePreviewDialog(const DUrlList &previewUrllist, QWidget *pa
 
 FilePreviewDialog::~FilePreviewDialog()
 {
+    emit signalCloseEvent();
     if (m_preview) {
         m_preview->deleteLater();
         m_preview = nullptr;
@@ -601,9 +602,9 @@ void FilePreviewDialog::done(int r)
 
 void FilePreviewDialog::DoneCurrent()
 {
-    if (this != nullptr && m_preview) {
-        m_preview->DoneCurrent();
-    }
+//    if (this != nullptr && m_preview) {
+//        m_preview->DoneCurrent();
+//    }
 }
 
 void FilePreviewDialog::playCurrentPreviewFile()
