@@ -44,6 +44,7 @@
 #include "deviceinfo/udisklistener.h"
 
 #include "controllers/vaultcontroller.h"
+#include "vaultglobaldefine.h"
 
 #include "utils.h"
 
@@ -672,7 +673,7 @@ void PropertyDialog::initConnect()
         }
     });
 
-    DAbstractFileWatcher *fileWatcher = DFileService::instance()->createFileWatcher(this, m_url);
+    DAbstractFileWatcher *fileWatcher = DFileService::instance()->createFileWatcher(this, m_url, this);
 
     connect(fileWatcher, &DAbstractFileWatcher::fileDeleted, this, &PropertyDialog::onChildrenRemoved);
     connect(fileWatcher, &DAbstractFileWatcher::fileMoved, this, [this](const DUrl & from, const DUrl & to) {
@@ -694,12 +695,12 @@ void PropertyDialog::updateFolderSize(qint64 size)
 
 void PropertyDialog::renameFile()
 {
-    bool donotShowSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool() };
+    bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
 
     const DAbstractFileInfoPointer &fileInfo = fileService->createFileInfo(this, m_url);
 
     QString fileName;
-    if (donotShowSuffix &&
+    if (!showSuffix &&
             fileInfo->isFile() &&
             !fileInfo->suffix().isEmpty() && !fileInfo->isDesktopFile()) {
         fileName = fileInfo->baseNameOfRename();
@@ -716,7 +717,7 @@ void PropertyDialog::renameFile()
     if (fileInfo->isFile()) {
 
         QString suffixStr{ fileInfo->suffix() };
-        if (suffixStr.isEmpty() || donotShowSuffix || fileInfo->isDesktopFile()) {
+        if (suffixStr.isEmpty() || !showSuffix || fileInfo->isDesktopFile()) {
             endPos = m_edit->toPlainText().length();
         } else if (m_edit->toPlainText().endsWith(suffixStr)) {
             endPos = m_edit->toPlainText().length() - fileInfo->suffix().length() - 1;
@@ -736,7 +737,7 @@ void PropertyDialog::showTextShowFrame()
 {
     const DAbstractFileInfoPointer &fileInfo = DFileService::instance()->createFileInfo(this, m_url);
 
-    bool donotShowSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffixOnRename).toBool() };
+    bool showSuffix{ DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowedFileSuffix).toBool() };
 
     QString newName = m_edit->toPlainText();
 
@@ -744,7 +745,7 @@ void PropertyDialog::showTextShowFrame()
         m_edit->setIsCanceled(true);
     }
 
-    if (donotShowSuffix && fileInfo->isFile() &&
+    if (!showSuffix && fileInfo->isFile() &&
             !fileInfo->suffix().isEmpty() && !fileInfo->isDesktopFile()) {
         newName += "." + fileInfo->suffix();
     }
@@ -1022,6 +1023,16 @@ void PropertyDialog::resizeEvent(QResizeEvent *event)
     DDialog::resizeEvent(event);
 }
 
+void PropertyDialog::showEvent(QShowEvent *event)
+{
+    DDialog::showEvent(event);
+
+    //展示时须设置弹窗尺寸，防止最小化后再次展示时窗口大小异常
+    QRect rc = geometry();
+    rc.setHeight(contentHeight() + ArrowLineExpand_SPACING * 2);
+    setGeometry(rc);
+}
+
 const QList<DDrawer *> &PropertyDialog::expandGroup() const
 {
     return m_expandGroup;
@@ -1191,15 +1202,15 @@ void PropertyDialog::initTextShowFrame(const QString &text)
 QFrame *PropertyDialog::createBasicInfoWidget(const DAbstractFileInfoPointer &info)
 {
     QFrame *widget = new QFrame(this);
-    SectionKeyLabel *sizeSectionLabel = new SectionKeyLabel(QObject::tr("Size"));
-    SectionKeyLabel *typeSectionLabel = new SectionKeyLabel(QObject::tr("Type"));
-    SectionKeyLabel *TimeCreatedSectionLabel = new SectionKeyLabel(QObject::tr("Time created"));
-    SectionKeyLabel *TimeReadSectionLabel = new SectionKeyLabel(QObject::tr("Time accessed"));
-    SectionKeyLabel *TimeModifiedSectionLabel = new SectionKeyLabel(QObject::tr("Time modified"));
-    SectionKeyLabel *sourcePathSectionLabel = new SectionKeyLabel(QObject::tr("Source path"));
+    SectionKeyLabel *sizeSectionLabel = new SectionKeyLabel(QObject::tr("Size"), widget);
+    SectionKeyLabel *typeSectionLabel = new SectionKeyLabel(QObject::tr("Type"), widget);
+    SectionKeyLabel *TimeCreatedSectionLabel = new SectionKeyLabel(QObject::tr("Time created"), widget);
+    SectionKeyLabel *TimeReadSectionLabel = new SectionKeyLabel(QObject::tr("Time accessed"), widget);
+    SectionKeyLabel *TimeModifiedSectionLabel = new SectionKeyLabel(QObject::tr("Time modified"), widget);
+    SectionKeyLabel *sourcePathSectionLabel = new SectionKeyLabel(QObject::tr("Source path"), nullptr);
 
     m_containSizeLabel = new SectionValueLabel(info->sizeDisplayName());
-    m_folderSizeLabel = new SectionValueLabel;
+    m_folderSizeLabel = new SectionValueLabel("", widget);
     SectionValueLabel *typeLabel = new SectionValueLabel(info->mimeTypeDisplayName());
     SectionValueLabel *timeCreatedLabel = nullptr;
     SectionValueLabel *timeReadLabel = nullptr;
@@ -1207,7 +1218,7 @@ QFrame *PropertyDialog::createBasicInfoWidget(const DAbstractFileInfoPointer &in
     if(VaultController::isRootDirectory(info->fileUrl().toLocalFile())){
         TimeModifiedSectionLabel->setText(QObject::tr("Time locked"));
         //! 保险箱根目录创建、访问、修改时间的读取
-        DFM_NAMESPACE::DFMSettings setting(QString("vaultTimeConfig"));
+        DFM_NAMESPACE::DFMSettings setting(VAULT_TIME_CONFIG_FILE);
         timeCreatedLabel = new SectionValueLabel(setting.value(QString("VaultTime"), QString("CreateTime")).toString());
         timeReadLabel = new SectionValueLabel(setting.value(QString("VaultTime"), QString("InterviewTime")).toString());
         if(setting.value(QString("VaultTime"), QString("LockTime")).toString().isEmpty())
@@ -1294,11 +1305,10 @@ QFrame *PropertyDialog::createBasicInfoWidget(const DAbstractFileInfoPointer &in
         sourcePathLabel->setToolTip(trashSourcePath);
         sourcePathLabel->setWordWrap(false);
         sourcePathLabel->setText(elidedStr);
+        sourcePathSectionLabel->setParent(widget);
         layout->addRow(sourcePathSectionLabel, sourcePathLabel);
     }
 
-
-
     if (info->fileUrl().isRecentFile()) {
         QString pathStr = info->filePath();
         SectionValueLabel *sourcePathLabel = new SectionValueLabel(pathStr);
@@ -1306,9 +1316,14 @@ QFrame *PropertyDialog::createBasicInfoWidget(const DAbstractFileInfoPointer &in
         sourcePathLabel->setToolTip(pathStr);
         sourcePathLabel->setWordWrap(false);
         sourcePathLabel->setText(elidedStr);
+        sourcePathSectionLabel->setParent(widget);
         layout->addRow(sourcePathSectionLabel, sourcePathLabel);
     }
 
+    if (!sourcePathSectionLabel->parent()) {
+        delete sourcePathSectionLabel;
+    }
+
     DGioSettings gsettings("com.deepin.dde.filemanager.general", "/com/deepin/dde/filemanager/general/");
 
     if (gsettings.value("property-dlg-hidefile-checkbox").toBool() && DFMFileListFile::supportHideByFile(info->filePath())
@@ -1376,6 +1391,15 @@ QList<QPair<QString, QString> > PropertyDialog::createLocalDeviceInfoWidget(cons
     quint64 fsUsed = info->extraProperties()["fsUsed"].toULongLong();
     quint64 fsFreeSize = info->extraProperties()["fsFreeSize"].toULongLong();
     quint64 fsSize = info->extraProperties()["fsSize"].toULongLong();
+    //fixed:CD display size error
+    if (static_cast<DFMRootFileInfo::ItemType>(info->fileType()) == DFMRootFileInfo::ItemType::UDisksOptical) {
+        DFMRootFileInfo *pFileInfo = dynamic_cast<DFMRootFileInfo *>(info.data());
+        QString strVolTag;
+        if (pFileInfo)
+            strVolTag = pFileInfo->getVolTag();
+        fsSize = DFMOpticalMediaWidget::g_mapCdStatusInfo[strVolTag].nTotal;
+        fsFreeSize = fsSize - DFMOpticalMediaWidget::g_mapCdStatusInfo[strVolTag].nUsage;
+    }
     quint64 fileCount = 0;
     DUrl redirectedFileUrl = info->redirectedFileUrl();
     if (!redirectedFileUrl.isEmpty()) {
@@ -1411,7 +1435,8 @@ QList<QPair<QString, QString> > PropertyDialog::createLocalDeviceInfoWidget(cons
         {DFMRootFileInfo::ItemType::GvfsSMB, QObject::tr("Network shared directory")},
         {DFMRootFileInfo::ItemType::GvfsMTP, QObject::tr("Android mobile device")},
         {DFMRootFileInfo::ItemType::GvfsGPhoto2, QObject::tr("Apple mobile device")},
-        {DFMRootFileInfo::ItemType::GvfsCamera, QObject::tr("Camera")}
+        {DFMRootFileInfo::ItemType::GvfsCamera, QObject::tr("Camera")},
+        {DFMRootFileInfo::ItemType::NotConnRemote, QObject::tr("Unconnected network shared directory")}
     };
 
     //fix GvfsGPhoto2协议对Apple mobile device判断有问题，再增加一层判断
@@ -1473,7 +1498,8 @@ QFrame *PropertyDialog::createInfoFrame(const QList<QPair<QString, QString> > &p
     }
 
     widget->setLayout(layout);
-    widget->setFixedHeight(EXTEND_FRAME_MAXHEIGHT);
+    //widget是最小高度时，藏语会发生截断，layout自适应，设置最小展示高度
+    widget->setMinimumHeight(EXTEND_FRAME_MAXHEIGHT);
     return widget;
 }
 
@@ -1565,6 +1591,10 @@ QFrame *PropertyDialog::createAuthorityManagementWidget(const DAbstractFileInfoP
     QComboBox *groupBox = new QComboBox;
     QComboBox *otherBox = new QComboBox;
 
+    ownerBox->view()->parentWidget()->setAttribute(Qt::WA_TranslucentBackground);
+    groupBox->view()->parentWidget()->setAttribute(Qt::WA_TranslucentBackground);
+    otherBox->view()->parentWidget()->setAttribute(Qt::WA_TranslucentBackground);
+
     DUrl parentUrl = info->parentUrl();
     DStorageInfo storageInfo(parentUrl.toLocalFile());
     const QString &fsType = storageInfo.fileSystemType();
