@@ -745,7 +745,7 @@ bool FileUtils::cpTemplateFileToTargetDir(const QString &targetdir, const QStrin
     return !AppController::createFile(templateFile, targetdir, baseName, windowId).isEmpty();
 }
 
-bool FileUtils::openFile(const QString &filePath)
+bool FileUtils::openFile(const QString &filePath, const QString &desktopFile)
 {
     bool result = false;
     if (QFileInfo(filePath).suffix() == "desktop") {
@@ -758,36 +758,44 @@ bool FileUtils::openFile(const QString &filePath)
     //QString mimetype = getFileMimetype(filePath);
     DAbstractFileInfoPointer info = DFileService::instance()->createFileInfo(nullptr, DUrl(FILE_ROOT + filePath));
     QString mimetype;
-    if (info && info->size() == 0 && info->exists()) {
+    if (Q_UNLIKELY(!filePath.contains("#")) && info && info->size() == 0 && info->exists()) {
         mimetype = info->mimeType().name();
     } else {
         mimetype = getFileMimetype(filePath);
     }
     /*********************************************************/
+
     QAtomicInteger<bool> isOpenNow = false;
-    QString defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
-    if (defaultDesktopFile.isEmpty()) {
-        if (isSmbUnmountedFile(DUrl::fromLocalFile(filePath))) {
-            mimetype = QString("inode/directory");
-            defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
-            isOpenNow = true;
-            mimetype = QString();
-        } else {
-            qDebug() << "no default application for" << filePath;
-            return false;
+    QString defaultDesktopFile;
+
+    if(!desktopFile.isEmpty() && isFileManagerSelf(desktopFile)) {
+        defaultDesktopFile = desktopFile;
+    } else {
+        defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
+        if (defaultDesktopFile.isEmpty()) {
+            if (isSmbUnmountedFile(DUrl::fromLocalFile(filePath))) {
+                mimetype = QString("inode/directory");
+                defaultDesktopFile = MimesAppsManager::getDefaultAppDesktopFileByMimeType(mimetype);
+                isOpenNow = true;
+                mimetype = QString();
+            } else {
+                qDebug() << "no default application for" << filePath;
+                return false;
+            }
         }
-    }
-    //此处会排除执行段(Exec=)包含dde-file-manager的desktop文件，需要对目录(inode/directory)类型及dde-open.desktop例外处理
-    if (!isOpenNow && isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory" && !defaultDesktopFile.contains("/dde-open.desktop")) {
-        QStringList recommendApps = mimeAppsManager->getRecommendedApps(DUrl::fromLocalFile(filePath));
-        recommendApps.removeOne(defaultDesktopFile);
-        if (recommendApps.count() > 0) {
-            defaultDesktopFile = recommendApps.first();
-        } else {
-            qDebug() << "no default application for" << filePath;
-            return false;
+        //此处会排除执行段(Exec=)包含dde-file-manager的desktop文件，需要对目录(inode/directory)类型及dde-open.desktop例外处理
+        if (!isOpenNow && isFileManagerSelf(defaultDesktopFile) && mimetype != "inode/directory" && !defaultDesktopFile.contains("/dde-open.desktop")) {
+            QStringList recommendApps = mimeAppsManager->getRecommendedApps(DUrl::fromLocalFile(filePath));
+            recommendApps.removeOne(defaultDesktopFile);
+            if (recommendApps.count() > 0) {
+                defaultDesktopFile = recommendApps.first();
+            } else {
+                qDebug() << "no default application for" << filePath;
+                return false;
+            }
         }
     }
+
     result = launchApp(defaultDesktopFile, QStringList() << DUrl::fromLocalFile(filePath).toString());
     if (result) {
         // workaround since DTK apps doesn't support the recent file spec.
@@ -1026,7 +1034,7 @@ bool FileUtils::launchApp(const QString &desktopFile, const QStringList &filePat
             if (t_file.isLocalFile()) {
                 t_filePath = t_file.toLocalFile();
             }
-            openFile(t_filePath);
+            openFile(t_filePath, desktopFile);
         }
         return true;
     }
@@ -1768,6 +1776,61 @@ void FileUtils::addRecentFile(const QString &filePath, const DesktopFile &deskto
     DRecentManager::addItem(filePath, recentData);
 }
 
+bool FileUtils::isContainProhibitPath(const QList<QUrl> &urls)
+{
+    // user home prohibit Paths
+    QStringList usrProhibitPaths;
+    usrProhibitPaths << QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DesktopLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DownloadLocation).first();
+
+    static QStringList fstabPaths = fstabProhibitPaths(usrProhibitPaths);
+    for (const auto &url : urls) {
+        // usr Prohibit Paths
+        if (!url.isEmpty() && (usrProhibitPaths.contains(url.path()) || fstabPaths.contains(url.path())))
+            return true;
+    }
+    return false;
+}
+
+bool FileUtils::isContainProhibitPath(const QUrl &url)
+{
+    QStringList usrProhibitPaths;
+    usrProhibitPaths << QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DesktopLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation).first()
+                     << QStandardPaths::standardLocations(QStandardPaths::DownloadLocation).first();
+
+    static QStringList fstabPaths = fstabProhibitPaths(usrProhibitPaths);
+    if (!url.isEmpty() && (usrProhibitPaths.contains(url.path()) || fstabPaths.contains(url.path())))
+        return true;
+    return false;
+}
+
+QStringList FileUtils::fstabProhibitPaths(const QStringList &usrProhibitPaths)
+{
+    QStringList tempList;
+    QList<QStringList> fstabInfo = catFstabFileInfo("defaults,bind");
+    for (const QStringList &temp : fstabInfo) {
+        if(!temp.isEmpty() && temp.count() >=4) {
+            for (QString path : usrProhibitPaths) {
+                if ((temp.at(1) == "/root" && path.left(5) == "/root") ||
+                        (temp.at(1) == "/home" && path.left(5) == "/home")) {
+                    tempList << path.replace(0, 5, temp.first());
+                }
+            }
+        }
+    }
+    return tempList;
+}
+
 bool FileUtils::appendCompress(const DUrl &toUrl, const DUrlList &fromUrlList)
 {
     if (!fromUrlList.isEmpty()) {
