@@ -86,7 +86,8 @@ DFMSideBar::DFMSideBar(QWidget *parent)
     // init view.
     m_sidebarView->setModel(m_sidebarModel);
     m_sidebarView->setItemDelegate(new DFMSideBarItemDelegate(m_sidebarView));
-    m_sidebarView->setViewportMargins(10, 0, m_sidebarView->verticalScrollBar()->sizeHint().width(), 0);
+    // #bug133653 侧边栏左右间距10个像素
+    m_sidebarView->setViewportMargins(10, 0, 10, 0);
     m_sidebarView->setContextMenuPolicy(Qt::CustomContextMenu);
     m_sidebarView->setFrameShape(QFrame::Shape::NoFrame);
     m_sidebarView->setAutoFillBackground(true);
