@@ -168,12 +168,6 @@ void DFMVaultRemovePages::closeEvent(QCloseEvent *event)
     DFMVaultPageBase::closeEvent(event);
 }
 
-DFMVaultRemovePages *DFMVaultRemovePages::instance()
-{
-    static DFMVaultRemovePages s_instance;
-    return &s_instance;
-}
-
 void DFMVaultRemovePages::showTop()
 {
     VaultController::ins()->setVauleCurrentPageMark(VaultPageMark::DELETEVAULTPAGE);
@@ -288,7 +282,7 @@ void DFMVaultRemovePages::slotCheckAuthorizationFinished(Authority::Result resul
 void DFMVaultRemovePages::onLockVault(int state)
 {
     if (m_bRemoveVault) {
-        if (state == 0) {
+        if (state == 0 || state == 1) {
             // 切换至删除界面
             showRemoveWidget();
             emit accepted();
