@@ -45,8 +45,6 @@
 
 DWIDGET_USE_NAMESPACE
 
-DFMVaultUnlockPages *DFMVaultUnlockPages::m_instance = nullptr;
-
 DFMVaultUnlockPages::DFMVaultUnlockPages(QWidget *parent)
     : DFMVaultPageBase(parent)
 {
@@ -96,7 +94,7 @@ DFMVaultUnlockPages::DFMVaultUnlockPages(QWidget *parent)
     m_tipsButton->setIcon(QIcon(":/icons/images/icons/light_32px.svg"));
 
     //! 找回密码页面
-    m_retrievePage = DFMVaultRetrievePassword::instance();
+    m_retrievePage = new DFMVaultRetrievePassword(this);
 
     // 主视图
     QFrame *mainFrame = new QFrame(this);
@@ -243,13 +241,6 @@ void DFMVaultUnlockPages::showToolTip(const QString &text, int duration, DFMVaul
     }
 }
 
-DFMVaultUnlockPages *DFMVaultUnlockPages::instance()
-{
-    if (!m_instance)
-        m_instance = new DFMVaultUnlockPages();
-    return m_instance;
-}
-
 void DFMVaultUnlockPages::hideEvent(QHideEvent *event)
 {
     if (m_frame)
