@@ -20,6 +20,7 @@
  */
 
 #include <gtest/gtest.h>
+#include <sanitizer/asan_interface.h>
 #include <gmock/gmock-matchers.h>
 #include <QApplication>
 
@@ -34,6 +35,12 @@ int main(int argc, char *argv[])
     QApplication app(argc,argv);
     testing::InitGoogleTest(&argc,argv);
     //不打印应用的输出日志
-    qInstallMessageHandler(noMessageHandler);
-    return RUN_ALL_TESTS();
+    //qInstallMessageHandler(noMessageHandler);
+    int res = RUN_ALL_TESTS();
+
+#ifdef ENABLE_TSAN_TOOL
+    __sanitizer_set_report_path("../../asan_dde-desktop.log");
+#endif
+
+    return res;
 }
