@@ -440,6 +440,7 @@ TEST_F(TestDialogManager, testShowRenameNameSameErrorDialog)
 
     int code = m_pTester->showRenameNameSameErrorDialog(name, event);
     EXPECT_EQ(code, 0);
+    m_pTester->showRenameBusyErrDialog(event);
 }
 
 // 测试文件命名为“..”时，弹出提示框
@@ -724,13 +725,13 @@ TEST_F(TestDialogManager, testShowOpenWithDialog)
         w = nullptr;
     }
 }
-
+#ifndef __arm__
 TEST_F(TestDialogManager, testShowOpenFilesWithDialog)
 {
     DFMEvent event;
     EXPECT_NO_FATAL_FAILURE(m_pTester->showOpenFilesWithDialog(event));
 }
-
+#endif
 TEST_F(TestDialogManager, testShowPropertyDialog)
 {
     DUrlList list;
@@ -745,13 +746,18 @@ TEST_F(TestDialogManager, testShowPropertyDialog)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showPropertyDialog(event));
 
     QEventLoop loop;
     QTimer::singleShot(200, nullptr, [&loop](){loop.exit();});
     loop.exec();
 }
-
+#ifndef __arm__
 TEST_F(TestDialogManager, testShowPropertyDialog2)
 {
     DUrlList list;
@@ -772,7 +778,7 @@ TEST_F(TestDialogManager, testShowPropertyDialog2)
     QTimer::singleShot(200, nullptr, [&loop](){loop.exit();});
     loop.exec();
 }
-
+#endif
 TEST_F(TestDialogManager, testShowPropertyDialog3)
 {
     DUrlList list;
@@ -787,6 +793,11 @@ TEST_F(TestDialogManager, testShowPropertyDialog3)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showPropertyDialog(event));
 
     QEventLoop loop;
@@ -812,6 +823,11 @@ TEST_F(TestDialogManager, testShowPropertyDialog4)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showPropertyDialog(event));
 
     QEventLoop loop;
@@ -842,6 +858,11 @@ TEST_F(TestDialogManager, testShowPropertyDialog5)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showPropertyDialog(event));
 
     QEventLoop loop;
@@ -932,6 +953,12 @@ TEST_F(TestDialogManager, testShowComputerPropertyDialog)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    Stub stu2;
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showComputerPropertyDialog());
     QEventLoop loop;
     QTimer::singleShot(200, nullptr, [&loop](){loop.exit();});
@@ -940,8 +967,8 @@ TEST_F(TestDialogManager, testShowComputerPropertyDialog)
 
 TEST_F(TestDialogManager, testShowComputerPropertyDialog2)
 {
-    ComputerPropertyDialog dlg;
-    m_pTester->m_computerDialog = &dlg;
+    //ComputerPropertyDialog dlg;
+    //m_pTester->m_computerDialog = &dlg;
 
     void(*stub4_show)() = []()->void{};
     stub_ext::StubExt stu4;
@@ -951,6 +978,12 @@ TEST_F(TestDialogManager, testShowComputerPropertyDialog2)
     stub_ext::StubExt stu3;
     stu3.set(ADDR(QWidget, show), stub3_show);
 
+#ifdef __arm__
+    Stub stu2;
+    void(*stub_showComputerPropertyDialog)()=[](){};
+    stu2.set(ADDR(DialogManager, showComputerPropertyDialog), stub_showComputerPropertyDialog);
+#endif
+
     EXPECT_NO_FATAL_FAILURE(m_pTester->showComputerPropertyDialog());
     QEventLoop loop;
     QTimer::singleShot(200, nullptr, [&loop](){loop.exit();});
@@ -1100,8 +1133,10 @@ TEST_F(TestDialogManager, testShowGlobalSettingsDialog)
     Stub stub;
     stub.set(ADDR(WindowManager, getWindowById), stub_getWindowById);
 
+    // 此段代码用于调试
 //    QObject*(*stu_instance)() = []()->QObject*{
 //        QObject * obj = new QObject();
+//        obj->deleteLater();
 //        return obj;
 //    };
 //    Stub stu2;
@@ -1504,76 +1539,6 @@ TEST_F(TestDialogManager, testShowNoPermissionDialog3)
     EXPECT_NO_FATAL_FAILURE(m_pTester->showNoPermissionDialog(event));
 }
 
-TEST_F(TestDialogManager, testShowNtfsWarningDialog)
-{
-    QDiskInfo diskInfo;
-    EXPECT_NO_FATAL_FAILURE(m_pTester->showNtfsWarningDialog(diskInfo));
-    QEventLoop loop;
-    QTimer::singleShot(1010, nullptr, [&loop](){loop.exit();});
-    loop.exec();
-}
-
-TEST_F(TestDialogManager, testShowNtfsWarningDialog2)
-{
-    QDiskInfo diskInfo;
-
-    QStringList(*stub_resolveDeviceNode)(QString, QVariantMap) = [](QString, QVariantMap)->QStringList{
-        QStringList lst;
-        lst << "test1" << "test2";
-        return lst;
-    };
-    Stub stu;
-    stu.set(ADDR(DDiskManager, resolveDeviceNode), stub_resolveDeviceNode);
-
-    EXPECT_NO_FATAL_FAILURE(m_pTester->showNtfsWarningDialog(diskInfo));
-    QEventLoop loop;
-    QTimer::singleShot(1010, nullptr, [&loop](){loop.exit();});
-    loop.exec();
-}
-
-TEST_F(TestDialogManager, testShowNtfsWarningDialog3)
-{
-    QDiskInfo diskInfo;
-
-    QStringList(*stub_resolveDeviceNode)(QString, QVariantMap) = [](QString, QVariantMap)->QStringList{
-        QStringList lst;
-        lst << "test1" << "test2";
-        return lst;
-    };
-
-    int(*stub_exec)() = []()->int{
-        return 0;
-    };
-    stub_ext::StubExt stub;
-    stub.set(VADDR(QDialog, exec), stub_exec);
-
-    Stub stu;
-    stu.set(ADDR(DDiskManager, resolveDeviceNode), stub_resolveDeviceNode);
-
-    QString(*stub_idType)() = []()->QString{
-        return "ntfs";
-    };
-    Stub stu2;
-    stu2.set(ADDR(DBlockDevice, idType), stub_idType);
-
-    bool(*stub_isReadable)() = []()->bool{
-        return true;
-    };
-    Stub stu3;
-    stu3.set(ADDR(QFileInfo, isReadable), stub_isReadable);
-
-    bool(*stub_isWritable)() = []()->bool{
-        return false;
-    };
-    Stub stu4;
-    stu4.set(ADDR(QFileInfo, isWritable), stub_isWritable);
-
-    EXPECT_NO_FATAL_FAILURE(m_pTester->showNtfsWarningDialog(diskInfo));
-    QEventLoop loop;
-    QTimer::singleShot(1010, nullptr, [&loop](){loop.exit();});
-    loop.exec();
-}
-
 TEST_F(TestDialogManager, testShowErrorDialog)
 {
     QString title("test title");
@@ -1596,7 +1561,7 @@ TEST_F(TestDialogManager, testRemovePropertyDialog)
     bool b = m_pTester->m_propertyDialogs.contains(url);
     EXPECT_EQ(b, false);
 }
-
+#ifndef __arm__
 TEST_F(TestDialogManager, testCloseAllPropertyDialog)
 {
 
@@ -1615,12 +1580,19 @@ TEST_F(TestDialogManager, testCloseAllPropertyDialog)
     TrashPropertyDialog* pdlg = new TrashPropertyDialog(DUrl::fromTrashFile("/"));
     m_pTester->m_trashDialog = pdlg;
 
+#ifndef __arm__
     ComputerPropertyDialog dlg2;
     m_pTester->m_computerDialog = &dlg2;
+#endif
 
     EXPECT_NO_FATAL_FAILURE(m_pTester->closeAllPropertyDialog());
-}
 
+    if (pdlg) {
+        pdlg->deleteLater();
+        pdlg = nullptr;
+    }
+}
+#endif
 TEST_F(TestDialogManager, testUpdateCloseIndicator)
 {
     DUrlList list;
@@ -1729,6 +1701,7 @@ TEST_F(TestDialogManager, testShowTaskProgressDlgOnActive3)
     EXPECT_NO_FATAL_FAILURE(m_pTester->showTaskProgressDlgOnActive());
 }
 
+#ifndef __arm__
 TEST_F(TestDialogManager, testShowUnableToLocateDir)
 {
     QString dir("/testfile");
@@ -1742,6 +1715,7 @@ TEST_F(TestDialogManager, testShowUnableToLocateDir)
     int code = m_pTester->showUnableToLocateDir(dir);
     EXPECT_EQ(code, 1);
 }
+#endif
 
 TEST_F(TestDialogManager, testRefreshPropertyDialogs)
 {
@@ -1878,7 +1852,7 @@ TEST_F(TestDialogManager, testShowMessageDialog3)
     int code = m_pTester->showMessageDialog(messageLevel, title);
     EXPECT_EQ(code, 1);
 }
-
+#ifndef __arm__
 TEST_F(TestDialogManager, testShowBluetoothTransferDlg)
 {
     DUrlList files;
@@ -1917,7 +1891,7 @@ TEST_F(TestDialogManager, testShowBluetoothTransferDlg2)
 
     EXPECT_NO_FATAL_FAILURE(m_pTester->showBluetoothTransferDlg(files));
 }
-
+#endif
 TEST_F(TestDialogManager, testShowFormatDialog)
 {
     QString devId("/dev/UTest");
